
; NSIS2 Script for GStreamer by LRN. Based on NSIS2 Script for GTK2-Runtime by Alexander Shaduri
; Compatible with NSIS 2.40

; The naming convention is:
; Product: GStreamer;
; Directory and package names: gstreamer.
; Each major (0.9, 0.10) version is placed in different directory.

; from Makefile
!define GST_MAJORMINOR "0.10"
!define PACKAGE_NAME "GStreamer"
!define PACKAGE_STRING "GStreamer 0.10.22.1"
!define PACKAGE_TARNAME "gstreamer"
!define PACKAGE_VERSION "0.10.22.1"
!define PACKAGE_VERSION_MAJOR "0"
!define PACKAGE_VERSION_MICRO "22"
!define PACKAGE_VERSION_MINOR "10"
!define PACKAGE_VERSION_NANO "1"
!define PACKAGE_VERSION_RELEASE "0.20090312.203504"

!define PRODUCT_PUBLISHER "GStreamer team"
!define PRODUCT_WEB_SITE "http://gstreamer.freedesktop.org/"

;!define PRODUCT_DIR_REGKEY "Software\Microsoft\Windows\CurrentVersion\App Paths\AppMainExe.exe"
!define PRODUCT_UNINST_ROOT_KEY "HKLM"
!define PRODUCT_UNINST_KEY "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PACKAGE_NAME}\${GST_MAJORMINOR}"

!define REGISTRY_APP_PATHS "Software\Microsoft\Windows\CurrentVersion\App Paths"


; AddToPath and friends should work with all users
!define ALL_USERS

; AddToPath, isNT, etc...
!include "nsi_custom.nsh"  ; local functions


; --------------- General Settings


; This compressor gives us the best results
SetCompressor /SOLID lzma

; Do a CRC check before installing
CRCCheck On

; This is used in titles
Name "${PACKAGE_NAME}"  ;  ${PACKAGE_VERSION}

; Output File Name
OutFile "gstreamer-${PACKAGE_VERSION}.exe"


; The Default Installation Directory
InstallDir "$COMMONFILES\${PACKAGE_NAME}\${GST_MAJORMINOR}"
;InstallDir "$WINDIR"
; detect the old installation
InstallDirRegKey HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" ""
;InstallDirRegKey HKLM "${PRODUCT_DIR_REGKEY}" ""

ShowInstDetails show
ShowUnInstDetails show





; --------------------- MUI INTERFACE

; MUI 2.0 compatible install
!include "MUI2.nsh"
!include "InstallOptions.nsh"

;Backgound Colors. uncomment to enable fullscreen.
; BGGradient 0000FF 000000 FFFFFF

; Icon "gstreamer.ico"
; UninstallIcon "gstreamer.ico"

; MUI Settings
!define MUI_ABORTWARNING
;!define MUI_ICON "nsi_install.ico"
!define MUI_ICON "gstreamer.ico"
;!define MUI_UNICON "nsi_uninstall.ico"
!define MUI_UNICON "gstreamer.ico"


; Things that need to be extracted on first (keep these lines before any File command!)
; Only useful for BZIP2 compression
ReserveFile "nsi_pathpage.ini"
;ReserveFile "nsi_configpage.ini"
ReserveFile "${NSISDIR}\Plugins\InstallOptions.dll"
!insertmacro MUI_RESERVEFILE_LANGDLL


; Remember language selection dialog settings.
; They will be removed during uninstall.
!define MUI_LANGDLL_REGISTRY_ROOT "${PRODUCT_UNINST_ROOT_KEY}"
!define MUI_LANGDLL_REGISTRY_KEY "${PRODUCT_UNINST_KEY}"
!define MUI_LANGDLL_REGISTRY_VALUENAME "NSIS:Language"


; Pages to show during installation
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "license.txt"
!insertmacro MUI_PAGE_COMPONENTS
Page custom PathPage  ; Custom page
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES

;!define MUI_FINISHPAGE_RUN "$INSTDIR\gtk2-runtime\gtk2_prefs.exe"
;!define MUI_FINISHPAGE_SHOWREADME "$INSTDIR\Example.file"
;!define MUI_FINISHPAGE_RUN_NOTCHECKED
!define MUI_FINISHPAGE_NOAUTOCLOSE
; !define MUI_FINISHPAGE_NOREBOOTSUPPORT
!insertmacro MUI_PAGE_FINISH



; Uninstaller page
!insertmacro MUI_UNPAGE_CONFIRM
UninstPage custom un.DeleteConfig ;Custom page
!insertmacro MUI_UNPAGE_INSTFILES



Function PathPage
  !insertmacro MUI_HEADER_TEXT "$(TEXT_IO_TITLE)" "$(TEXT_IO_SUBTITLE)"
  !insertmacro INSTALLOPTIONS_DISPLAY "nsi_pathpage.ini"
FunctionEnd



Function un.DeleteConfig
;  !insertmacro MUI_HEADER_TEXT "$(TEXT_IO_TITLE)" "$(TEXT_IO_SUBTITLE)"
;  !insertmacro INSTALLOPTIONS_DISPLAY "nsi_configpage.ini"
FunctionEnd



; Language files
!insertmacro MUI_LANGUAGE "English"
!insertmacro MUI_LANGUAGE "Russian"


; --------------- END MUI



;Description
LangString DESC_SecCopyUI ${LANG_ENGLISH} "GStreamer"
LangString DESC_SecCopyUI ${LANG_RUSSIAN} "GStreamer"

LangString TEXT_IO_TITLE ${LANG_ENGLISH} "GStreamer"
LangString TEXT_IO_TITLE ${LANG_RUSSIAN} "GStreamer"

LangString TEXT_IO_SUBTITLE ${LANG_ENGLISH} "Additional options"
LangString TEXT_IO_SUBTITLE ${LANG_RUSSIAN} "Additional options"


;License Page Introduction
;LicenseText "You must agree to this license before installing."
;License Data
;LicenseData /LANG=${LANG_ENGLISH} "license.txt"
;LicenseData /LANG=${LANG_RUSSIAN} "license.txt"





; --------------- START INSTALLATION


Function .onInit

  !insertmacro INSTALLOPTIONS_EXTRACT "nsi_pathpage.ini"

  ;Font
  ; Push Tahoma
  ; Push 8

  ;Languages
  ; !insertmacro MUI_LANGDLL_PUSH "English"
  ; !insertmacro MUI_LANGDLL_PUSH "Russian"

  !insertmacro MUI_LANGDLL_DISPLAY

  Push 2 ;F ;22 = number of languages, F = change font

  ;Language selection
  LangDLL::LangDialog "Installer Language" "Please select a language."

  Pop $LANGUAGE
  StrCmp $LANGUAGE "cancel" 0 +2
  Abort


	; detect GTK installation (any of available versions)
	ReadRegStr $R0 HKLM "SOFTWARE\GTK\2.0" "DllPath"
	StrCmp $R0 "" no_gtk

	goto have_gtk

	no_gtk:
	MessageBox MB_OKCANCEL|MB_ICONEXCLAMATION \
	"GTK2-Runtime is not installed. This product needs it to function properly.$\n\
	Please install GTK2-Runtime from http://gtk-win.sf.net/ first.$\n$\n\
	Click 'Cancel' to abort the installation \
	or 'OK' to continue anyway." \
	IDOK have_gtk
	Abort

	have_gtk:
	; do nothing

	; detect previous installation
	ReadRegStr $R0 HKLM "${PRODUCT_UNINST_KEY}" "UninstallString"
	StrCmp $R0 "" done

	MessageBox MB_OKCANCEL|MB_ICONEXCLAMATION \
		"${PACKAGE_NAME} is already installed. $\n$\nClick `OK` to remove the \
		previous version or `Cancel` to continue anyway." \
		/SD IDOK IDOK uninst
		; Abort
	goto done

  ;Run the old uninstaller
  uninst:
  ClearErrors
  IfSilent silent_uninst nosilent_uninst
  
  nosilent_uninst:
  ExecWait '$R0 _?=$INSTDIR'  ;Do not copy the uninstaller to a temp file
  goto uninst_continue

  silent_uninst:
  ExecWait '$R0 /S _?=$INSTDIR'
  
  uninst_continue:

  IfErrors no_remove_uninstaller

  ;You can either use Delete /REBOOTOK in the uninstaller or add some code
  ;here to remove to remove the uninstaller. Use a registry key to check
  ;whether the user has chosen to uninstall. If you are using an uninstaller
  ;components page, make sure all sections are uninstalled.
  no_remove_uninstaller:

  done:
  ; old installation not found


FunctionEnd




; ----------------- INSTALLATION TYPES

InstType "Recommended"
;InstType "Full"
;InstType "Minimal"




!define LIB_INSTDIR $R1
!define USE_DLL_NAME $R2

Section "GStreamer binaries (required)" SecGST
SectionIn 1 2 RO

  SetOverwrite On


  StrCpy ${LIB_INSTDIR} "$INSTDIR"
  StrCpy ${USE_DLL_NAME} "bin"

  SetOutPath "${LIB_INSTDIR}\bin"


  ; NOTE: If you add or remove any of these,
  ; be sure to do the same in the uninstall section.

   File bin\gst-feedback.exe
   ; shell-script
   ;File bin\gst-feedback-${GST_MAJORMINOR}
   ; broken?
   ;File bin\gst-inspect.exe
   File bin\gst-inspect-${GST_MAJORMINOR}.exe
   ; broken?
   ;File bin\gst-launch.exe
   File bin\gst-launch-${GST_MAJORMINOR}.exe
   ; broken?
   ;File bin\gst-typefind.exe
   File bin\gst-typefind-${GST_MAJORMINOR}.exe
   ; broken?
   ;File bin\gst-xmlinspect.exe
   File bin\gst-xmlinspect-${GST_MAJORMINOR}.exe
   ; broken?
   ;File bin\gst-xmllaunch.exe
   File bin\gst-xmllaunch-${GST_MAJORMINOR}.exe
   File bin\libgstbase-${GST_MAJORMINOR}-0.dll
   File bin\libgstcheck-${GST_MAJORMINOR}-0.dll
   File bin\libgstcontroller-${GST_MAJORMINOR}-0.dll
   File bin\libgstdataprotocol-${GST_MAJORMINOR}-0.dll
   File bin\libgstnet-${GST_MAJORMINOR}-0.dll
   File bin\libgstreamer-${GST_MAJORMINOR}-0.dll

  SetOutPath "${LIB_INSTDIR}\deps"
   File /r deps\libxml2.dll

  SetOutPath "$INSTDIR\lib\gstreamer-${GST_MAJORMINOR}"
   File /r lib\gstreamer-${GST_MAJORMINOR}\libgstcoreelements.dll
   File /r lib\gstreamer-${GST_MAJORMINOR}\libgstcoreindexers.dll

  ; We need don't need to add a registry path if the libraries
  ; are installed to "bin". This allows us to have multiple
  ; non-conflicting installations.
  StrCmp ${USE_DLL_NAME} "bin" goto_nobinreg
    WriteRegStr HKLM "${REGISTRY_APP_PATHS}\gst-inspect-${GST_MAJORMINOR}.exe" "Path" "${LIB_INSTDIR}\bin"
    WriteRegStr HKLM "${REGISTRY_APP_PATHS}\gst-launch-${GST_MAJORMINOR}.exe" "Path" "${LIB_INSTDIR}\bin"
    WriteRegStr HKLM "${REGISTRY_APP_PATHS}\gst-typefind-${GST_MAJORMINOR}.exe" "Path" "${LIB_INSTDIR}\bin"
    WriteRegStr HKLM "${REGISTRY_APP_PATHS}\gst-xmlinspect-${GST_MAJORMINOR}.exe" "Path" "${LIB_INSTDIR}\bin"
    WriteRegStr HKLM "${REGISTRY_APP_PATHS}\gst-xmllaunch-${GST_MAJORMINOR}.exe" "Path" "${LIB_INSTDIR}\bin"
  goto_nobinreg:

  SetOutPath "$INSTDIR\gstreamer"
  ; File gstreamer-postinstall.bat ; this file is generated now
  ;File license.txt
  ;File license_gpl.txt
  File license_lgpl.txt
  File license_libxml.txt
  ;File license_jpeg.txt
  ;File license_png.txt
  ;File license_zlib.txt
  ;File license_glut32.txt


  ; this script updates some config files, but it's unsafe
  ; (gstreamer may not work afterwards), so don't call it.
  Push $INSTDIR\gstreamer\gst-postinstall.bat
  Call WritePostInstall
  ; update pango.modules, not working for now
  ; Exec '$INSTDIR\gstreamer\gst-postinstall.bat'

SectionEnd ; end of gstreamer section


; Section descriptions
!insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
  !insertmacro MUI_DESCRIPTION_TEXT ${SecGST} "GStreamer binaries"
;  !insertmacro MUI_DESCRIPTION_TEXT ${SecGtkPrefs} "GTK2 Preference Utility to change the theme and font of GTK2 applications"
;  !insertmacro MUI_DESCRIPTION_TEXT ${SecLocales} "Additional translations (some are incomplete)"
!insertmacro MUI_FUNCTION_DESCRIPTION_END



; ------------------ POST INSTALL


!define B_SET_PATH $R6

Section -post

  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "InstallationDirectory" "$INSTDIR"
  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "DllPath" "${LIB_INSTDIR}\bin"
  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "Vendor" "${PRODUCT_PUBLISHER}"
  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "PackageVersion" "${PACKAGE_VERSION}"
  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "Version" "${GST_MAJORMINOR}"
;  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "BinVersion" "${PACKAGE_VERSION_MAJOR}.${PACKAGE_VERSION_MINOR}.${PACKAGE_VERSION_MICRO}.${PACKAGE_VERSION_NANO}"
  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "DllDirName" "${USE_DLL_NAME}"  ; lib, bin, or ""


  ; We don't need to be compatible with anything - we're the only guys with installer in the town
  ; compat with installer from http://gimp-win.sourceforge.net/
  ;WriteRegStr HKLM "SOFTWARE\GTK\2.0" "Path" "$INSTDIR"
  ;WriteRegStr HKLM "SOFTWARE\GTK\2.0" "Version" "${GTK_VERSION}"
  ; dropline's GTK
  ;WriteRegStr HKLM "SOFTWARE\GTK\2.0" "DllPath" "${LIB_INSTDIR}\bin"

  WriteRegStr HKLM "${PRODUCT_UNINST_KEY}" "DisplayName" "${PACKAGE_NAME}"
  WriteRegStr HKLM "${PRODUCT_UNINST_KEY}" "UninstallString" "$INSTDIR\gstreamer_uninst.exe"

  ; We don't need this, MUI takes care for us
  ;WriteRegStr HKCU "Software\${PRODUCT_NAME}" "Installer Language" $LANGUAGE


  ; uninstall shortcut
  CreateDirectory "$SMPROGRAMS\GStreamer"
  CreateShortCut "$SMPROGRAMS\GStreamer\Uninstall GStreamer.lnk" "$INSTDIR\gstreamer_uninst.exe" "" ""
  WriteIniStr "$SMPROGRAMS\GStreamer\Go to the website.url" "InternetShortcut" "URL" "${PRODUCT_WEB_SITE}"


  ; Write $INSTDIR\gstreamer\gst-env.bat
  ; This script sets the GTK environment variables
  DetailPrint "Generating $INSTDIR\gstreamer\gst-env.bat"
  Push $INSTDIR\gstreamer\gst-env.bat
  Push $INSTDIR
  Call WriteEnvBat
  DetailPrint "Done"


  StrCpy $R8 "0"  ; $PATH or not

  ; Read a value from an InstallOptions INI File
  ; Do we need to reboot? (if the $PATH has changed)
  !insertmacro INSTALLOPTIONS_READ ${B_SET_PATH} "nsi_pathpage.ini" "Field 1" "State"
  StrCmp ${B_SET_PATH} "1" "" goto_noreboot

  ; The user requested to add the libdir to $PATH.
  StrCpy $R8 "1"

  Push $INSTDIR
  Call AddToPath

  Push $1
  Call IsNT
  Pop $1
  StrCmp $1 0 goto_reboot goto_noreboot

  goto_reboot:
  SetRebootFlag true

  goto_noreboot:

  WriteRegStr HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "UsingSystemPath" $R8

  ; write out uninstaller
  WriteUninstaller "$INSTDIR\gstreamer_uninst.exe"
  

SectionEnd ; post





; ---------------- UNINSTALL



Function un.onInit
;  !insertmacro INSTALLOPTIONS_EXTRACT "nsi_configpage.ini"

;  ;Get language from registry. MUI takes care for us.
;  ;ReadRegStr $LANGUAGE HKCU "Software\${PRODUCT_NAME}" "Installer Language"
;  !insertmacro MUI_UNGETLANGUAGE
;  MessageBox MB_ICONQUESTION|MB_YESNO|MB_DEFBUTTON2 "Are you sure you want to completely remove $(^Name) and all of its components?" /SD IDYES IDYES +2
;  Abort
FunctionEnd



Function un.onUninstSuccess
  HideWindow
  MessageBox MB_ICONINFORMATION|MB_OK "$(^Name) was successfully removed from your computer." /SD IDOK
FunctionEnd





Var DLL_PATH  ; same as ${LIB_INSTDIR}
Var DLL_DIR_NAME  ; "lib", "bin" or ""
Var SYSTEM_PATHED  ; GStreamer using $PATH?


Section Uninstall

  SetAutoClose false

  ; For PATH removal
  ReadRegStr $DLL_PATH HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "DllPath"
  ReadRegStr $DLL_DIR_NAME HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "DllDirName"
  ReadRegStr $SYSTEM_PATHED HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}" "UsingSystemPath"


  ; Delete config file?
  ;!insertmacro INSTALLOPTIONS_READ $R5 "nsi_configpage.ini" "Field 1" "State"
  ;StrCmp $R5 "1" goto_skip_config

;  Delete "$INSTDIR\etc\gtk-2.0\gtkrc"


  ;goto_skip_config:

; RMDir /r "$INSTDIR\etc\fonts"
; RMDir /r "$INSTDIR\etc\pango"
; Delete "$INSTDIR\etc\gtk-2.0\gdk-pixbuf.loaders"
; Delete "$INSTDIR\etc\gtk-2.0\gtk.immodules"
; Delete "$INSTDIR\etc\gtk-2.0\gtkrc.default"
; Delete "$INSTDIR\etc\gtk-2.0\im-multipress.conf"
; RMDir "$INSTDIR\etc\gtk-2.0" ; only if empty
; RMDir "$INSTDIR\etc" ; only if empty


  ; add delete commands to delete whatever files/registry keys/etc you installed here.
  Delete "$INSTDIR\gstreamer_uninst.exe"

  ;DeleteRegKey HKLM "SOFTWARE\GTK\2.0"  ; dropline, etc...
  ;DeleteRegKey /ifempty HKLM "SOFTWARE\GTK"  ; don't damage other installations

  DeleteRegKey HKLM "SOFTWARE\${PACKAGE_NAME}\${GST_MAJORMINOR}"
  DeleteRegKey /ifempty HKLM "SOFTWARE\${PACKAGE_NAME}"
  DeleteRegKey HKLM "${PRODUCT_UNINST_KEY}"

  ; FIXME: Do we have this registry key?
  ; DeleteRegKey HKCU "Software\${PRODUCT_NAME}"


  ; All dll files. We delete them before /bin and /lib, so that
  ; the directories are empty afterwards.

   Delete $DLL_PATH\gst-feedback.exe
   ; shell-script
   ;Delete $DLL_PATH\gst-feedback-${GST_MAJORMINOR}
   ; broken?
   ;Delete $DLL_PATH\gst-inspect.exe
   Delete $DLL_PATH\gst-inspect-${GST_MAJORMINOR}.exe
   ; broken?
   ;Delete $DLL_PATH\gst-launch.exe
   Delete $DLL_PATH\gst-launch-${GST_MAJORMINOR}.exe
   ; broken?
   ;Delete $DLL_PATH\gst-typefind.exe
   Delete $DLL_PATH\gst-typefind-${GST_MAJORMINOR}.exe
   ; broken?
   ;Delete $DLL_PATH\gst-xmlinspect.exe
   Delete $DLL_PATH\gst-xmlinspect-${GST_MAJORMINOR}.exe
   ; broken?
   ;Delete $DLL_PATH\gst-xmllaunch.exe
   Delete $DLL_PATH\gst-xmllaunch-${GST_MAJORMINOR}.exe
   Delete $DLL_PATH\libgstbase-${GST_MAJORMINOR}-0.dll
   Delete $DLL_PATH\libgstcheck-${GST_MAJORMINOR}-0.dll
   Delete $DLL_PATH\libgstcontroller-${GST_MAJORMINOR}-0.dll
   Delete $DLL_PATH\libgstdataprotocol-${GST_MAJORMINOR}-0.dll
   Delete $DLL_PATH\libgstnet-${GST_MAJORMINOR}-0.dll
   Delete $DLL_PATH\libgstreamer-${GST_MAJORMINOR}-0.dll

   Delete $INSTDIR\deps\libxml2.dll

   Delete $INSTDIR\lib\gstreamer-${GST_MAJORMINOR}\libgstcoreelements.dll
   Delete $INSTDIR\lib\gstreamer-${GST_MAJORMINOR}\libgstcoreindexers.dll

  ; some helper files here
  RMDir /r "$INSTDIR\gstreamer"

  RMDir "$INSTDIR\bin"  ; only if empty
  RMDir "$INSTDIR\deps"  ; only if empty
  RMDir "$INSTDIR\lib\gstreamer-${GST_MAJORMINOR}"  ; only if empty
  RMDir "$INSTDIR\lib"  ; only if empty

  StrCmp $DLL_DIR_NAME "bin" goto_nobinunreg
   DeleteRegKey HKLM "${REGISTRY_APP_PATHS}\gst-inspect-${GST_MAJORMINOR}.exe"
   DeleteRegKey HKLM "${REGISTRY_APP_PATHS}\gst-launch-${GST_MAJORMINOR}.exe"
   DeleteRegKey HKLM "${REGISTRY_APP_PATHS}\gst-typefind-${GST_MAJORMINOR}.exe"
   DeleteRegKey HKLM "${REGISTRY_APP_PATHS}\gst-xmlinspect-${GST_MAJORMINOR}.exe"
   DeleteRegKey HKLM "${REGISTRY_APP_PATHS}\gst-xmllaunch-${GST_MAJORMINOR}.exe"
  goto_nobinunreg:

  RMDir "$INSTDIR"  ; delete only if empty

  Delete "$SMPROGRAMS\GStreamer\Uninstall GStreamer.lnk"
  Delete "$SMPROGRAMS\GStreamer\Go to the website.url"

  RMDir "$SMPROGRAMS\GStreamer"  ; only if empty, other plugins may be there

  ; this is kinda dangerous, since we can un-path something like c:\windows
  ; FIXME: check this. doesn't work in win98.

  ; Setting $PATH was not requested during installation
  StrCmp $SYSTEM_PATHED "0" goto_nopath

  Push $DLL_PATH
  Call un.RemoveFromPath

  ; MessageBox MB_OK "$DLL_PATH removed from PATH" /SD IDOK

  goto_nopath:

SectionEnd ; end of uninstall section





; ----------------- CUSTOM POST (UN)INSTALL FUNCTIONS


; WriteEnvBat
Function WriteEnvBat
  Pop $R0 ; Output file
  Pop $R1 ; instdir
  Push $R9
    FileOpen $R9 $R0 w
    FileWrite $R9 "@set GSTREAMER_PREFIX=$R1$\r$\n"
    FileWrite $R9 "$\r$\n"
    FileWrite $R9 "@echo Setting environment variables for GStreamer.$\r$\n"
    FileWrite $R9 "$\r$\n"
    FileWrite $R9 "@echo.$\r$\n"
    FileWrite $R9 "@echo set PATH=%GSTREAMER_PREFIX%\bin;%GSTREAMER_PREFIX%\deps;%%PATH%%$\r$\n"
    FileWrite $R9 "@set PATH=%GSTREAMER_PREFIX%\bin;%GSTREAMER_PREFIX%\deps;%PATH%$\r$\n"
    FileWrite $R9 "$\r$\n"
    FileWrite $R9 "@echo.$\r$\n"
    FileWrite $R9 "@echo set GST_PLUGIN_PATH=%GSTREAMER_PREFIX%\lib\gstreamer-${GST_MAJORMINOR}$\r$\n"
    FileWrite $R9 "@set GST_PLUGIN_PATH=%GSTREAMER_PREFIX%\lib\gstreamer-${GST_MAJORMINOR}$\r$\n"
    FileWrite $R9 "$\r$\n"
    FileWrite $R9 "@echo.$\r$\n"
    FileClose $R9
  Pop $R9
FunctionEnd



; WritePostInstall
Function WritePostInstall
  Pop $R0 ; Output file
  Push $R9

    FileOpen $R9 $R0 w
    FileWrite $R9 "@echo off$\r$\n"
    ;FileWrite $R9 "$\"$INSTDIR\bin\pango-querymodules.exe$\" > $\"$INSTDIR\etc\pango\pango.modules$\"$\r$\n"
    ;FileWrite $R9 "rem $\"$INSTDIR\bin\gdk-pixbuf-query-loaders.exe$\" > $\"$INSTDIR\etc\gtk-2.0\gdk-pixbuf.loaders$\"$\r$\n"
    ;FileWrite $R9 "$\"$INSTDIR\bin\gtk-query-immodules-2.0.exe$\" > $\"$INSTDIR\etc\gtk-2.0\gtk.immodules$\"$\r$\n"
    ;FileWrite $R9 "rem $\"$INSTDIR\bin\gtk-update-icon-cache.exe$\"$\r$\n"
    FileClose $R9

 Pop $R9
FunctionEnd




; eof